All Classes and Interfaces
Class
Description
Base exception for unpredictable / checked (untestable states) exceptions,
providing functionality for exception specific multi-language messages.
Base exception for hidden (unchecked) / subsystem exceptions, providing
functionality for exception specific multi-language messages.
Base exception for I/O exceptions, providing functionality for exception
specific multi-language messages.
Base exception for runtime (unchecked) / predictable (testable states)
exceptions, providing functionality for exception specific multi-language
messages.
A bug exception is thrown when it surely must be a bug when reaching the
place when the
BugException is being thrown.A
DisposedException may be thrown in case of using of a disposed
instance's methods.Provides an accessor for an error code property.
Provides a builder method for a error code property returning the builder
for applying multiple build operations.
Provides a mutator for an error code property.
Provides an error code property.
Provides an accessor for a error aMessage property.
Provides a builder method for a error aMessage property returning the
builder for applying multiple build operations.
Provides a mutator for a error aMessage property.
Provides a error aMessage property.
Provides an accessor for an
Exception property.Provides a builder method for a exception property returning the builder
for applying multiple build operations.
Provides a mutator for an
Exception property.Provides a an
Exception property.The
Exceptional interface provides means for threads to wait (sleep)
when calling Exceptional.catchException() till a next Exception occurs
or till the waiting (sleeping) threads are released.The
ExceptionHandler interface provides means to handle exceptions
which usually are occurring inside daemon threads and are usually hidden from
the (business) logic.Provides an accessor for an
ExceptionHandler property.Provides a builder method for a exception handler property returning the
builder for applying multiple build operations.
Provides a mutator for an
ExceptionHandler property.Provides a an
ExceptionHandler property.An integrity exception is thrown whenever the integrity of data may be
violated.
Thrown in case an instance being locked is still being accessed in a
modifying way (see
org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).Thrown in case an instance being locked is still being accessed in a
modifying way (see
org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).Thrown when marshaling / serializing an object fails.
The
MessageDetails enumeration provides different detail levels when
generating exception messages from Throwable exceptions using the
Trap.toMessage(MessageDetails) method.Produces a
MessageStrategy.getMessage(Throwable) message when called upon the
MessageStrategy.MESSAGE enumeration or a localized message when called upon the
MessageStrategy.LOCALIZED_MESSAGE enumeration from a provided Throwable
instance (strategy pattern).Thrown in case opening or accessing an open line (connection, junction, link)
caused timeout problems.
Interface declaring base exception functionality for all of refcodes
exceptions.
An
UnhandledEnumBugException is thrown in case an enumeration was
encountered which is not being considered by the code (e.g. in a
switch/case-statement): We have a coding error!An
UnhandledValueBugException is thrown in case a value was
encountered which is not being considered by the code (e.g. in a
switch/case-statement): We have a coding error!Thrown when unmarshaling / deserializing an object fails.
A verify exception is thrown in case the verification of the result (of an
algorithm) failed.
Thrown to signal that an operation is being vetoed by a third party observing
the invocation of the given operation.
Thrown to signal that an operation is being vetoed by a third party
observing the invocation of the given operation.