Class AbstractException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
- Direct Known Subclasses:
LockedException, MarshalException, UnmarshalException, VetoException
Base exception for unpredictable / checked (untestable states) exceptions,
providing functionality for exception specific multi-language messages.
Unpredictable exceptions must be declared or explicitly caught. You as a
programmer cannot take care to prevent such exceptions by according
(business) logic. Such exceptions may be network connection loss or external
peripheral failure.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionAbstractException(String aMessage) Instantiates the classAbstractException.AbstractException(String aMessage, String aErrorCode) Instantiates the classAbstractException.AbstractException(String aMessage, Throwable aCause) Instantiates the classAbstractException.AbstractException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classAbstractException.AbstractException(Throwable aCause) Instantiates the classAbstractException.AbstractException(Throwable aCause, String aErrorCode) Instantiates the classAbstractException. -
Method Summary
Modifier and TypeMethodDescriptionProvides the according exception code.Methods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
AbstractException
Instantiates the classAbstractException.- See Also:
-
AbstractException
-
AbstractException
-
AbstractException
Instantiates the classAbstractException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
AbstractException
Instantiates the classAbstractException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
AbstractException
Instantiates the classAbstractException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
-
Method Details
-
getMessage
- Overrides:
getMessagein classThrowable
-
getErrorCode
Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- Specified by:
getErrorCodein interfaceErrorCodeAccessor- Returns:
- The exception code in question.
-