Class AbstractHiddenException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap

public abstract class AbstractHiddenException extends RuntimeException implements Trap
Base exception for hidden (unchecked) / subsystem exceptions, providing functionality for exception specific multi-language messages. A hidden exception is an exception not representing the behavior of a system by its declared checked and runtime exceptions. Moreover, hidden exceptions may originate from subsystems wrapped by a system without the wrapping system being able to declare the actual subsystem's aCause in its declarations (due to e.g. interface compliance reasons). You as a programmer cannot take care to prevent such exception as them may be even undocumented. Such exceptions may be exceptions wrapping an actual aCause. Requiring a hidden exceptions may point to problems of your software design, the use of hidden exceptrions should be avoided.
See Also:
  • Constructor Details

  • Method Details

    • getErrorCode

      public String getErrorCode()
      Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      Specified by:
      getErrorCode in interface ErrorCodeAccessor
      Returns:
      The exception code in question.