Class AbstractIOException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
Direct Known Subclasses:
TimeoutIOException

public abstract class AbstractIOException extends IOException implements Trap
Base exception for I/O exceptions, providing functionality for exception specific multi-language messages. Unpredictable exceptions must be declared or explicitly caught. You as a programmer cannot take care to prevent such exceptions by according (business) logic. Such exceptions may be network connection loss or external peripheral failure.
See Also:
  • Constructor Details

    • AbstractIOException

      public AbstractIOException(String aMessage, Throwable aCause)
      Instantiates the class AbstractIOException.
      See Also:
    • AbstractIOException

      public AbstractIOException(String aMessage)
      Instantiates the class AbstractIOException.
      See Also:
    • AbstractIOException

      public AbstractIOException(Throwable aCause)
      Instantiates the class AbstractIOException.
      See Also:
    • AbstractIOException

      public AbstractIOException(String aMessage, Throwable aCause, String aErrorCode)
      Instantiates the class AbstractIOException.
      Parameters:
      aErrorCode - The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      See Also:
    • AbstractIOException

      public AbstractIOException(String aMessage, String aErrorCode)
      Instantiates the class AbstractIOException.
      Parameters:
      aErrorCode - The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      See Also:
    • AbstractIOException

      public AbstractIOException(Throwable aCause, String aErrorCode)
      Instantiates the class AbstractIOException.
      Parameters:
      aErrorCode - The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      See Also:
  • Method Details

    • getErrorCode

      public String getErrorCode()
      Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      Specified by:
      getErrorCode in interface ErrorCodeAccessor
      Returns:
      The exception code in question.