Class AbstractRuntimeException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
Direct Known Subclasses:
BugException, DisposedException, IntegrityException, LockedException.LockedRuntimeException, VerifyRuntimeException, VetoException.VetoRuntimeException

public abstract class AbstractRuntimeException extends RuntimeException implements Trap
Base exception for runtime (unchecked) / predictable (testable states) exceptions, providing functionality for exception specific multi-language messages. Regarding unchecked exception, "The Java Programming Language", by Gosling, Arnold, and Holmes says "... Unchecked runtime exceptions represent conditions that, generally speaking, reflect errors in your program's logic and cannot be reasonably recovered from at run time ...". Though you as a programmer can take care by according (business) logic to prevent such exception. Such exceptions may be accessing disposed components or any other aCause where you can test a state beforehand.
See Also:
  • Constructor Details

  • Method Details

    • getMessage

      public String getMessage()
      Overrides:
      getMessage in class Throwable
    • getErrorCode

      public String getErrorCode()
      Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.
      Specified by:
      getErrorCode in interface ErrorCodeAccessor
      Returns:
      The exception code in question.