Class BugException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.exception.BugException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
- Direct Known Subclasses:
UnhandledEnumBugException,UnhandledValueBugException
A bug exception is thrown when it surely must be a bug when reaching the
place when the
BugException is being thrown. Example: In case an
enumeration is evaluated and an "unexpected" enumeration value is identified
by the code (it does not know how to continue with that explicit enumeration
value), then either the enumeration has been wrongly extended by new values
or the code as not been extended to process that newly added enumeration. Her
in a switch / case's "default" block you may throw a BugException.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionBugException(String aMessage) Instantiates the classBugException.BugException(String aMessage, String aErrorCode) Instantiates the classBugException.BugException(String aMessage, Throwable aCause) Instantiates the classBugException.BugException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classBugException.BugException(Throwable aCause) Instantiates the classBugException.BugException(Throwable aCause, String aErrorCode) Instantiates the classBugException. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
BugException
-
BugException
Instantiates the classBugException.- See Also:
-
BugException
-
BugException
Instantiates the classBugException.- See Also:
-
BugException
Instantiates the classBugException.- See Also:
-
BugException
Instantiates the classBugException.- See Also:
-