Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionAccessor<E extends Throwable>
-
- Type Parameters:
E- The actual exception type.
- All Known Subinterfaces:
ExceptionAccessor.ExceptionProperty<E>
public interface ExceptionAccessor<E extends Throwable>Provides an accessor for anExceptionproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceExceptionAccessor.ExceptionBuilder<E extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<E,B>>Provides a builder method for a exception property returning the builder for applying multiple build operations.static interfaceExceptionAccessor.ExceptionMutator<E>Provides a mutator for anExceptionproperty.static interfaceExceptionAccessor.ExceptionProperty<E extends Throwable>Provides a anExceptionproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description EgetException()Retrieves the exception from the exception property.
-
-
-
Method Detail
-
getException
E getException()
Retrieves the exception from the exception property.- Returns:
- The exception stored by the exception property.
-
-