Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<EXC,B>>
-
- Type Parameters:
EXC- The actual exception type.B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- ExceptionAccessor<EXC extends Throwable>
public static interface ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<EXC,B>>Provides a builder method for a exception property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithException(EXC aException)Sets the exception for the exception property.
-