Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionAccessor.ExceptionMutator<EXC extends Throwable>
-
- Type Parameters:
EXC- The actual exception type.
- All Known Subinterfaces:
ExceptionAccessor.ExceptionProperty<EXC>
- Enclosing interface:
- ExceptionAccessor<EXC extends Throwable>
public static interface ExceptionAccessor.ExceptionMutator<EXC extends Throwable>Provides a mutator for anExceptionproperty.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidsetException(EXC aException)Sets the exception for the exception property.
-
-
-
Method Detail
-
setException
void setException(EXC aException)
Sets the exception for the exception property.- Parameters:
aException- The exception to be stored by the exception property.
-
-