Interface ExceptionAccessor.ExceptionProperty<EXC extends Throwable>
- Type Parameters:
EXC- The actual exception type.
- All Superinterfaces:
ExceptionAccessor<EXC>, ExceptionAccessor.ExceptionMutator<EXC>
- Enclosing interface:
ExceptionAccessor<EXC extends Throwable>
public static interface ExceptionAccessor.ExceptionProperty<EXC extends Throwable>
extends ExceptionAccessor<EXC>, ExceptionAccessor.ExceptionMutator<EXC>
Provides a an
Exception property.-
Nested Class Summary
Nested classes/interfaces inherited from interface ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<EXC,B>, ExceptionAccessor.ExceptionMutator<EXC>, ExceptionAccessor.ExceptionProperty<EXC> -
Method Summary
Modifier and TypeMethodDescriptiondefault EXCletException(EXC aException) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenException(setter) as ofExceptionAccessor.ExceptionMutator.setException(Throwable)and returns the very same value (getter).Methods inherited from interface ExceptionAccessor
getExceptionMethods inherited from interface ExceptionAccessor.ExceptionMutator
setException
-
Method Details
-
letException
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenException(setter) as ofExceptionAccessor.ExceptionMutator.setException(Throwable)and returns the very same value (getter).- Parameters:
aException- TheExceptionto set (viaExceptionAccessor.ExceptionMutator.setException(Throwable)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-