Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandler<EXC extends Throwable>
- Type Parameters:
EXC- theThrowabletype
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
The
ExceptionHandler interface provides means to handle exceptions
which usually are occurring inside daemon threads and are usually hidden from
the (business) logic. Such Exception instances usually just get
logged, no customizable reaction upon such exceptions is possible. This
interface enables to process to such Exception instances by providing
a custom implementation if this interface.-
Method Summary
Modifier and TypeMethodDescriptionvoidonException(EXC aException) This method is to be overwritten by a custom implementation and is invoked by a daemon thread upon a caughtException.
-
Method Details
-
onException
This method is to be overwritten by a custom implementation and is invoked by a daemon thread upon a caughtException.- Parameters:
aException- The exception to be handled.
-