Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandlerAccessor<EXC extends Throwable>
- Type Parameters:
EXC- TheExceptionbeing handled by theExceptionHandler.
- All Known Subinterfaces:
ExceptionHandlerAccessor.ExceptionHandlerProperty<EXC>
public interface ExceptionHandlerAccessor<EXC extends Throwable>
Provides an accessor for an
ExceptionHandler property.-
Nested Class Summary
Nested ClassesModifier and TypeInterfaceDescriptionstatic interfaceExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC, B>> Provides a builder method for a exception handler property returning the builder for applying multiple build operations.static interfaceProvides a mutator for anExceptionHandlerproperty.static interfaceProvides a anExceptionHandlerproperty. -
Method Summary
Modifier and TypeMethodDescriptionRetrieves the exception handler from the exception handler property.
-
Method Details
-
getExceptionHandler
ExceptionHandler<EXC> getExceptionHandler()Retrieves the exception handler from the exception handler property.- Returns:
- The exception handler stored by the exception handler property.
-