Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC,B>>
-
- Type Parameters:
EXC- TheExceptionbeing handled by theExceptionHandler.B- The builder to return in order to be able to apply multiple build operations.
- Enclosing interface:
- ExceptionHandlerAccessor<EXC extends Throwable>
public static interface ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC,B>>Provides a builder method for a exception handler property returning the builder for applying multiple build operations.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description BwithExceptionHandler(ExceptionHandler<EXC> aExceptionHandler)Sets the exception handler for the exception handler property.
-
-
-
Method Detail
-
withExceptionHandler
B withExceptionHandler(ExceptionHandler<EXC> aExceptionHandler)
Sets the exception handler for the exception handler property.- Parameters:
aExceptionHandler- The exception handler to be stored by the exception handler property.- Returns:
- The builder for applying multiple build operations.
-
-