Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandlerAccessor.ExceptionHandlerMutator<EXC extends Throwable>
- Type Parameters:
EXC- TheExceptionbeing handled by theExceptionHandler.
- All Known Subinterfaces:
ExceptionHandlerAccessor.ExceptionHandlerProperty<EXC>
- Enclosing interface:
- ExceptionHandlerAccessor<EXC extends Throwable>
public static interface ExceptionHandlerAccessor.ExceptionHandlerMutator<EXC extends Throwable>
Provides a mutator for an
ExceptionHandler property.-
Method Summary
Modifier and TypeMethodDescriptionvoidsetExceptionHandler(ExceptionHandler<EXC> aExceptionHandler) Sets the exception handler for the exception handler property.
-
Method Details
-
setExceptionHandler
Sets the exception handler for the exception handler property.- Parameters:
aExceptionHandler- The exception handler to be stored by the exception handler property.
-