- All Implemented Interfaces:
Serializable,Comparable<MessageStrategy>,Constable
Produces a
getMessage(Throwable) message when called upon the
MESSAGE enumeration or a localized message when called upon the
LOCALIZED_MESSAGE enumeration from a provided Throwable
instance (strategy pattern).-
Nested Class Summary
Nested classes/interfaces inherited from class java.lang.Enum
Enum.EnumDesc<E extends Enum<E>> -
Enum Constant Summary
Enum ConstantsEnum ConstantDescriptionUsed to produce localized exception messages fromExceptioninstances (as of theThrowable.getLocalizedMessage()method).Used to produce exception messages fromExceptioninstances (as of theThrowable.getMessage()method). -
Method Summary
Modifier and TypeMethodDescriptionstatic MessageStrategyReturns the enum constant of this class with the specified name.static MessageStrategy[]values()Returns an array containing the constants of this enum class, in the order they are declared.
-
Enum Constant Details
-
MESSAGE
Used to produce exception messages fromExceptioninstances (as of theThrowable.getMessage()method). -
LOCALIZED_MESSAGE
Used to produce localized exception messages fromExceptioninstances (as of theThrowable.getLocalizedMessage()method).
-
-
Method Details
-
values
Returns an array containing the constants of this enum class, in the order they are declared.- Returns:
- an array containing the constants of this enum class, in the order they are declared
-
valueOf
Returns the enum constant of this class with the specified name. The string must match exactly an identifier used to declare an enum constant in this class. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum class has no constant with the specified nameNullPointerException- if the argument is null
-