Class RuntimeIOException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.exception.RuntimeIOException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
Unchecked exception with the same semantics as the
IOException.- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionRuntimeIOException(String aMessage) Instantiates the classRuntimeIOException.RuntimeIOException(String aMessage, String aErrorCode) Instantiates the classRuntimeIOException.RuntimeIOException(String aMessage, Throwable aCause) Instantiates the classRuntimeIOException.RuntimeIOException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classRuntimeIOException.RuntimeIOException(Throwable aCause) Instantiates the classRuntimeIOException.RuntimeIOException(Throwable aCause, String aErrorCode) Instantiates the classRuntimeIOException. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
RuntimeIOException
Instantiates the classRuntimeIOException.- See Also:
-
RuntimeIOException
Instantiates the classRuntimeIOException.- See Also:
-
RuntimeIOException
Instantiates the classRuntimeIOException.- See Also:
-
RuntimeIOException
-
RuntimeIOException
Instantiates the classRuntimeIOException.- See Also:
-
RuntimeIOException
-
-
Method Details
-
getErrorCode
Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- Specified by:
getErrorCodein interfaceErrorCodeAccessor- Overrides:
getErrorCodein classAbstractRuntimeException- Returns:
- The exception code in question.
-