- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- java.io.IOException
-
- org.refcodes.exception.AbstractIOException
-
- org.refcodes.exception.TimeoutIOException
-
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
public class TimeoutIOException extends AbstractIOException
Thrown in case opening or accessing an open line (connection, junction, link) caused timeout problems.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description TimeoutIOException(long aTimeoutInMs, String message)Instantiates a new open timeout exception.TimeoutIOException(long aTimeoutInMs, String aMessage, String aErrorCode)Instantiates a new open timeout exception.TimeoutIOException(long aTimeoutInMs, String message, Throwable cause)Instantiates a new open timeout exception.TimeoutIOException(long aTimeoutInMs, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new open timeout exception.TimeoutIOException(long aTimeoutInMs, Throwable cause)Instantiates a new open timeout exception.TimeoutIOException(long aTimeoutInMs, Throwable aCause, String aErrorCode)Instantiates a new open timeout exception.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description longgetTimeoutInMs()The timeout attribute in milliseconds.-
Methods inherited from class org.refcodes.exception.AbstractIOException
getErrorCode
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, String aMessage, String aErrorCode)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in msaMessage- the messageaErrorCode- the error code
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, String aMessage, Throwable aCause, String aErrorCode)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in msaMessage- the messageaCause- the causeaErrorCode- the error code
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, String message, Throwable cause)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in msmessage- the messagecause- the cause
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, String message)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in msmessage- the message
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, Throwable aCause, String aErrorCode)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in msaCause- the causeaErrorCode- the error code
-
TimeoutIOException
public TimeoutIOException(long aTimeoutInMs, Throwable cause)Instantiates a new open timeout exception.- Parameters:
aTimeoutInMs- the timeout in mscause- the cause
-
-