java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.exception.VetoException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
Thrown to signal that an operation is being vetoed by a third party observing
the invocation of the given operation. It's occurrence is unpredictable for
the caller of the operation.
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classThrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionVetoException(String aMessage) Instantiates a new veto exception.VetoException(String aMessage, String aErrorCode) Instantiates a new veto exception.VetoException(String aMessage, Throwable aCause) Instantiates a new veto exception.VetoException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new veto exception.VetoException(Throwable aCause) Instantiates a new veto exception.VetoException(Throwable aCause, String aErrorCode) Instantiates a new veto exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
VetoException
Instantiates a new veto exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
VetoException
Instantiates a new veto exception. -
VetoException
Instantiates a new veto exception. -
VetoException
Instantiates a new veto exception.- Parameters:
aMessage- The aMessage describing this exception.
-
VetoException
Instantiates a new veto exception. -
VetoException
Instantiates a new veto exception.
-