Class VetoException.VetoRuntimeException

All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
Enclosing class:
VetoException

public static class VetoException.VetoRuntimeException extends AbstractRuntimeException
Thrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation. It's occurrence is unpredictable for the caller of the operation.
See Also: