Uses of Class
org.refcodes.exception.AbstractException
-
Uses of AbstractException in org.refcodes.exception
Subclasses of AbstractException in org.refcodes.exceptionModifier and TypeClassDescriptionclassThrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).classThrown when marshaling / serializing an object fails.classThrown when unmarshaling / deserializing an object fails.classThrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.