Uses of Class
org.refcodes.exception.BugException
-
Uses of BugException in org.refcodes.exception
Subclasses of BugException in org.refcodes.exceptionModifier and TypeClassDescriptionclassAnUnhandledEnumBugExceptionis thrown in case an enumeration was encountered which is not being considered by the code (e.g. in a switch/case-statement): We have a coding error!classAnUnhandledValueBugExceptionis thrown in case a value was encountered which is not being considered by the code (e.g. in a switch/case-statement): We have a coding error!