Uses of Interface
org.refcodes.exception.ExceptionHandler
-
Uses of ExceptionHandler in org.refcodes.exception
Methods in org.refcodes.exception that return ExceptionHandlerModifier and TypeMethodDescriptionExceptionHandlerAccessor.getExceptionHandler()Retrieves the exception handler from the exception handler property.default ExceptionHandler<EXC> ExceptionHandlerAccessor.ExceptionHandlerProperty.letExceptionHandler(ExceptionHandler<EXC> aExceptionHandler) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenExceptionHandler(setter) as ofExceptionHandlerAccessor.ExceptionHandlerMutator.setExceptionHandler(ExceptionHandler)and returns the very same value (getter).Methods in org.refcodes.exception with parameters of type ExceptionHandlerModifier and TypeMethodDescriptiondefault ExceptionHandler<EXC> ExceptionHandlerAccessor.ExceptionHandlerProperty.letExceptionHandler(ExceptionHandler<EXC> aExceptionHandler) This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenExceptionHandler(setter) as ofExceptionHandlerAccessor.ExceptionHandlerMutator.setExceptionHandler(ExceptionHandler)and returns the very same value (getter).voidExceptionHandlerAccessor.ExceptionHandlerMutator.setExceptionHandler(ExceptionHandler<EXC> aExceptionHandler) Sets the exception handler for the exception handler property.ExceptionHandlerAccessor.ExceptionHandlerBuilder.withExceptionHandler(ExceptionHandler<EXC> aExceptionHandler) Sets the exception handler for the exception handler property.