Uses of Enum Class
org.refcodes.exception.ExceptionMessageStrategy
-
Uses of ExceptionMessageStrategy in org.refcodes.exception
Methods in org.refcodes.exception that return ExceptionMessageStrategyModifier and TypeMethodDescriptionstatic ExceptionMessageStrategyReturns the enum constant of this class with the specified name.static ExceptionMessageStrategy[]ExceptionMessageStrategy.values()Returns an array containing the constants of this enum class, in the order they are declared.