Uses of Enum Class
org.refcodes.exception.MessageStrategy
-
Uses of MessageStrategy in org.refcodes.exception
Subclasses with type arguments of type MessageStrategy in org.refcodes.exceptionModifier and TypeClassDescriptionenumProduces aMessageStrategy.getMessage(Throwable)message when called upon theMessageStrategy.MESSAGEenumeration or a localized message when called upon theMessageStrategy.LOCALIZED_MESSAGEenumeration from a providedThrowableinstance (strategy pattern).Methods in org.refcodes.exception that return MessageStrategyModifier and TypeMethodDescriptionstatic MessageStrategyReturns the enum constant of this class with the specified name.static MessageStrategy[]MessageStrategy.values()Returns an array containing the constants of this enum class, in the order they are declared.