Module org.refcodes.exception
Package org.refcodes.exception
package org.refcodes.exception
-
ClassDescriptionBase exception for unpredictable / checked (untestable states) exceptions, providing functionality for exception specific multi-language messages.Base exception for hidden (unchecked) / subsystem exceptions, providing functionality for exception specific multi-language messages.Base exception for I/O exceptions, providing functionality for exception specific multi-language messages.Base exception for runtime (unchecked) / predictable (testable states) exceptions, providing functionality for exception specific multi-language messages.A bug exception is thrown when it surely must be a bug when reaching the place when the
BugExceptionis being thrown.ADisposedExceptionmay be thrown in case of using of a disposed instance's methods.Provides an accessor for an error code property.Provides a builder method for a error code property returning the builder for applying multiple build operations.Provides a mutator for an error code property.Provides an error code property.Provides an accessor for a error aMessage property.Provides a builder method for a error aMessage property returning the builder for applying multiple build operations.Provides a mutator for a error aMessage property.Provides a error aMessage property.ExceptionAccessor<EXC extends Throwable>Provides an accessor for anExceptionproperty.ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<EXC, B>> Provides a builder method for a exception property returning the builder for applying multiple build operations.ExceptionAccessor.ExceptionMutator<EXC extends Throwable>Provides a mutator for anExceptionproperty.ExceptionAccessor.ExceptionProperty<EXC extends Throwable>Provides a anExceptionproperty.Exceptional<EXC extends Throwable>TheExceptionalinterface provides means for threads to wait (sleep) when callingExceptional.catchException()till a nextExceptionoccurs or till the waiting (sleeping) threads are released.ExceptionHandler<EXC extends Throwable>TheExceptionHandlerinterface provides means to handle exceptions which usually are occurring inside daemon threads and are usually hidden from the (business) logic.ExceptionHandlerAccessor<EXC extends Throwable>Provides an accessor for anExceptionHandlerproperty.ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC, B>> Provides a builder method for a exception handler property returning the builder for applying multiple build operations.Provides a mutator for anExceptionHandlerproperty.Provides a anExceptionHandlerproperty.An integrity exception is thrown whenever the integrity of data may be violated.Unchecked exception with the same semantics as theIOException.Thrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).Thrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).Thrown when marshaling / serializing an object fails.TheMessageDetailsenumeration provides different detail levels when generating exception messages fromThrowableexceptions using theTrap.toMessage(MessageDetails)method.Produces aMessageStrategy.getMessage(Throwable)message when called upon theMessageStrategy.MESSAGEenumeration or a localized message when called upon theMessageStrategy.LOCALIZED_MESSAGEenumeration from a providedThrowableinstance (strategy pattern).Thrown in case opening or accessing an open line (connection, junction, link) caused timeout problems.Interface declaring base exception functionality for all of refcodes exceptions.Thrown when unmarshaling / deserializing an object fails.A verify exception is thrown in case the verification of the result (of an algorithm) failed.Thrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.Thrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.