All Classes Interface Summary Class Summary Exception Summary
| Class |
Description |
| AbstractException |
Base exception for unpredictable / checked (untestable states) exceptions,
providing functionality for exception specific multi-language messages.
|
| AbstractHiddenException |
Base exception for hidden (unchecked) / subsystem exceptions, providing
functionality for exception specific multi-language messages.
|
| AbstractIOException |
Base exception for I/O exceptions, providing functionality for exception
specific multi-language messages.
|
| AbstractRuntimeException |
Base exception for runtime (unchecked) / predictable (testable states)
exceptions, providing functionality for exception specific multi-language
messages.
|
| BugException |
Exception bugs (unchecked).
|
| ErrorCodeAccessor |
Provides an accessor for an error code property.
|
| ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>> |
Provides a builder method for a error code property returning the builder
for applying multiple build operations.
|
| ErrorCodeAccessor.ErrorCodeMutator |
Provides a mutator for an error code property.
|
| ErrorCodeAccessor.ErrorCodeProperty |
Provides an error code property.
|
| ErrorMessageAccessor |
Provides an accessor for a error message property.
|
| ErrorMessageAccessor.ErrorMessageBuilder<B extends ErrorMessageAccessor.ErrorMessageBuilder<B>> |
Provides a builder method for a error message property returning the
builder for applying multiple build operations.
|
| ErrorMessageAccessor.ErrorMessageMutator |
Provides a mutator for a error message property.
|
| ErrorMessageAccessor.ErrorMessageProperty |
Provides a error message property.
|
| ExceptionAccessor<EXC extends Throwable> |
Provides an accessor for an Exception property.
|
| ExceptionAccessor.ExceptionBuilder<EXC extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<EXC,B>> |
Provides a builder method for a exception property returning the builder
for applying multiple build operations.
|
| ExceptionAccessor.ExceptionMutator<EXC extends Throwable> |
Provides a mutator for an Exception property.
|
| ExceptionAccessor.ExceptionProperty<EXC extends Throwable> |
|
| Exceptional<EXC extends Throwable> |
|
| ExceptionHandler<EXC extends Throwable> |
The ExceptionHandler interface provides means to handle exceptions
which usually are occurring inside daemon threads and are usually hidden from
the (business) logic.
|
| ExceptionHandlerAccessor<EXC extends Throwable> |
|
| ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC,B>> |
Provides a builder method for a exception handler property returning the
builder for applying multiple build operations.
|
| ExceptionHandlerAccessor.ExceptionHandlerMutator<EXC extends Throwable> |
|
| ExceptionHandlerAccessor.ExceptionHandlerProperty<EXC extends Throwable> |
|
| ExceptionUtility |
Utility class for simplifying the work with exceptions.
|
| IntegrityException |
An integrity exception is thrown whenever the integrity of data may be
violated.
|
| IORuntimeException |
Unchecked exception with the same semantics as the IOException.
|
| LockedException |
Thrown in case an instance being locked is still being accessed in a
modifying way (see org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).
|
| LockedException.LockedRuntimeException |
Thrown in case an instance being locked is still being accessed in a
modifying way (see org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).
|
| MarshalException |
Thrown when marshaling / serializing an object fails.
|
| TimeoutIOException |
Thrown in case opening or accessing an open line (connection, junction, link)
caused timeout problems.
|
| Trap |
Interface declaring base exception functionality for all of refcodes
exceptions.
|
| UnmarshalException |
Thrown when unmarshaling / deserializing an object fails.
|
| VerifyRuntimeException |
A verify exception is thrown in case the verification of the result (of an
algorithm) failed.
|
| VetoException |
Thrown to signal that an operation is being vetoed by a third party observing
the invocation of the given operation.
|
| VetoException.VetoRuntimeException |
Thrown to signal that an operation is being vetoed by a third party
observing the invocation of the given operation.
|