Class AbstractIOException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.io.IOException
org.refcodes.exception.AbstractIOException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
- Direct Known Subclasses:
TimeoutIOException
Base exception for I/O exceptions, providing functionality for exception
specific multi-language messages. Unpredictable exceptions must be declared
or explicitly caught. You as a programmer cannot take care to prevent such
exceptions by according (business) logic. Such exceptions may be network
connection loss or external peripheral failure.
- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionAbstractIOException(String aMessage) Instantiates the classAbstractIOException.AbstractIOException(String aMessage, String aErrorCode) Instantiates the classAbstractIOException.AbstractIOException(String aMessage, Throwable aCause) Instantiates the classAbstractIOException.AbstractIOException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classAbstractIOException.AbstractIOException(Throwable aCause) Instantiates the classAbstractIOException.AbstractIOException(Throwable aCause, String aErrorCode) Instantiates the classAbstractIOException. -
Method Summary
Methods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
AbstractIOException
Instantiates the classAbstractIOException.- See Also:
-
AbstractIOException
-
AbstractIOException
-
AbstractIOException
Instantiates the classAbstractIOException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
AbstractIOException
Instantiates the classAbstractIOException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
AbstractIOException
Instantiates the classAbstractIOException.- Parameters:
aErrorCode- The exception code to be assigned to the exception. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- See Also:
-
-
Method Details
-
getErrorCode
Provides the according exception code. An exception code can be provided when creating an exception and it can be used by the business logic to retrieve a language depended exception aMessage (multi-language support) from a language pack instead of just providing the single language aMessage as being stored by the default exceptions.- Specified by:
getErrorCodein interfaceErrorCodeAccessor- Returns:
- The exception code in question.
-