Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionAccessor.ExceptionProperty<E extends Throwable>
- Type Parameters:
E- the element type
- All Superinterfaces:
ExceptionAccessor<E>,ExceptionAccessor.ExceptionMutator<E>
- Enclosing interface:
- ExceptionAccessor<E extends Throwable>
public static interface ExceptionAccessor.ExceptionProperty<E extends Throwable> extends ExceptionAccessor<E>, ExceptionAccessor.ExceptionMutator<E>
Provides a an
Exception property.-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ExceptionAccessor
ExceptionAccessor.ExceptionBuilder<E extends Throwable,B extends ExceptionAccessor.ExceptionBuilder<E,B>>, ExceptionAccessor.ExceptionMutator<E>, ExceptionAccessor.ExceptionProperty<E extends Throwable> -
Method Summary
Modifier and Type Method Description default EletException(E aException)This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenException(setter) as ofExceptionAccessor.ExceptionMutator.setException(Object)and returns the very same value (getter).Methods inherited from interface org.refcodes.exception.ExceptionAccessor
getExceptionMethods inherited from interface org.refcodes.exception.ExceptionAccessor.ExceptionMutator
setException
-
Method Details
-
letException
This method stores and passes through the given argument, which is very useful for builder APIs: Sets the givenException(setter) as ofExceptionAccessor.ExceptionMutator.setException(Object)and returns the very same value (getter).- Parameters:
aException- TheExceptionto set (viaExceptionAccessor.ExceptionMutator.setException(Object)).- Returns:
- Returns the value passed for it to be used in conclusive processing steps.
-