Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandler<EXC extends Throwable>
-
- Type Parameters:
EXC- theThrowabletype
- Functional Interface:
- This is a functional interface and can therefore be used as the assignment target for a lambda expression or method reference.
@FunctionalInterface public interface ExceptionHandler<EXC extends Throwable>
TheExceptionHandlerinterface provides means to handle exceptions which usually are occurring inside daemon threads and are usually hidden from the (business) logic. SuchExceptioninstances usually just get logged, no customizable reaction upon such exceptions is possible. This interface enables to process to suchExceptioninstances by providing a custom implementation if this interface.
-
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description voidonException(EXC aException)This method is to be overwritten by a custom implementation and is invoked by a daemon thread upon a caughtException.
-