Module org.refcodes.exception
Package org.refcodes.exception
Interface ExceptionHandlerAccessor<EXC extends Throwable>
-
- Type Parameters:
EXC- TheExceptionbeing handled by theExceptionHandler.
- All Known Subinterfaces:
ExceptionHandlerAccessor.ExceptionHandlerProperty<EXC>
public interface ExceptionHandlerAccessor<EXC extends Throwable>Provides an accessor for anExceptionHandlerproperty.
-
-
Nested Class Summary
Nested Classes Modifier and Type Interface Description static interfaceExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC extends Throwable,B extends ExceptionHandlerAccessor.ExceptionHandlerBuilder<EXC,B>>Provides a builder method for a exception handler property returning the builder for applying multiple build operations.static interfaceExceptionHandlerAccessor.ExceptionHandlerMutator<EXC extends Throwable>Provides a mutator for anExceptionHandlerproperty.static interfaceExceptionHandlerAccessor.ExceptionHandlerProperty<EXC extends Throwable>Provides a anExceptionHandlerproperty.
-
Method Summary
All Methods Instance Methods Abstract Methods Modifier and Type Method Description ExceptionHandler<EXC>getExceptionHandler()Retrieves the exception handler from the exception handler property.
-
-
-
Method Detail
-
getExceptionHandler
ExceptionHandler<EXC> getExceptionHandler()
Retrieves the exception handler from the exception handler property.- Returns:
- The exception handler stored by the exception handler property.
-
-