Class LockedException
java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.exception.LockedException
- All Implemented Interfaces:
Serializable, ErrorCodeAccessor, Trap
Thrown in case an instance being locked is still being accessed in a
modifying way (see
org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).- See Also:
-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classThrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).Nested classes/interfaces inherited from interface ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionLockedException(String aMessage) LockedException(String aMessage, String aErrorCode) LockedException(String aMessage, Throwable aCause) LockedException(String aMessage, Throwable aCause, String aErrorCode) LockedException(Throwable aCause) LockedException(Throwable aCause, String aErrorCode) -
Method Summary
Methods inherited from class AbstractException
getErrorCode, getMessageMethods inherited from class Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
LockedException
-
LockedException
-
LockedException
-
LockedException
-
LockedException
-
LockedException
-