java.lang.Object
java.lang.Throwable
java.lang.Exception
org.refcodes.exception.AbstractException
org.refcodes.exception.LockedException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
Thrown in case an instance being locked is still being accessed in a
modifying way (see
org.refcodes.mixin.Lockable in the
refcodes-mixin artifact).-
Nested Class Summary
Nested ClassesModifier and TypeClassDescriptionstatic classThrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionLockedException(String aMessage) Instantiates a new locked exception.LockedException(String aMessage, String aErrorCode) Instantiates a new locked exception.LockedException(String aMessage, Throwable aCause) Instantiates a new locked exception.LockedException(String aMessage, Throwable aCause, String aErrorCode) Instantiates a new locked exception.LockedException(Throwable aCause) Instantiates a new locked exception.LockedException(Throwable aCause, String aErrorCode) Instantiates a new locked exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
toLocalizedMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
LockedException
Instantiates a new locked exception.- Parameters:
aMessage- The aMessage describing this exception.aErrorCode- The error code identifying this exception.
-
LockedException
Instantiates a new locked exception. -
LockedException
Instantiates a new locked exception. -
LockedException
Instantiates a new locked exception.- Parameters:
aMessage- The aMessage describing this exception.
-
LockedException
Instantiates a new locked exception. -
LockedException
Instantiates a new locked exception.
-