- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.exception.LockedException
-
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
public class LockedException extends AbstractException implements Serializable
Thrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classLockedException.LockedRuntimeExceptionThrown in case an instance being locked is still being accessed in a modifying way (seeorg.refcodes.mixin.Lockablein the refcodes-mixin artifact).-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description LockedException(String message)Instantiates a new locked exception.LockedException(String aMessage, String aErrorCode)Instantiates a new locked exception.LockedException(String message, Throwable cause)Instantiates a new locked exception.LockedException(String aMessage, Throwable aCause, String aErrorCode)Instantiates a new locked exception.LockedException(Throwable cause)Instantiates a new locked exception.LockedException(Throwable aCause, String aErrorCode)Instantiates a new locked exception.
-
Method Summary
-
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCode
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
LockedException
public LockedException(String aMessage, String aErrorCode)
Instantiates a new locked exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
LockedException
public LockedException(String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new locked exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
LockedException
public LockedException(String message, Throwable cause)
Instantiates a new locked exception.- Parameters:
message- the messagecause- the cause
-
LockedException
public LockedException(String message)
Instantiates a new locked exception.- Parameters:
message- the message
-
LockedException
public LockedException(Throwable aCause, String aErrorCode)
Instantiates a new locked exception.- Parameters:
aCause- the causeaErrorCode- the error code
-
LockedException
public LockedException(Throwable cause)
Instantiates a new locked exception.- Parameters:
cause- the cause
-
-