- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.exception.UnmarshalException
-
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
public class UnmarshalException extends AbstractException
Thrown when unmarshaling / deserializing an object fails.- See Also:
- Serialized Form
-
-
Nested Class Summary
-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description UnmarshalException(String aMessage)Instantiates a new unmarshal exception.UnmarshalException(String aMessage, int aOffset)Instantiates a new unmarshal exception.UnmarshalException(String aMessage, int aOffset, Throwable aCause)Instantiates a new unmarshal exception.UnmarshalException(String aMessage, String aErrorCode)Instantiates a new unmarshal exception.UnmarshalException(String message, Throwable cause)Instantiates a new unmarshal exception.UnmarshalException(String aMessage, Throwable aCause, String aErrorCode)Instantiates a new unmarshal exception.UnmarshalException(Throwable cause)Instantiates a new unmarshal exception.UnmarshalException(Throwable aCause, String aErrorCode)Instantiates a new unmarshal exception.
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description intgetOffset()In case of a char sequence, the offset represents the position at which unmarshaling failed.-
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCode
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
UnmarshalException
public UnmarshalException(String aMessage)
Instantiates a new unmarshal exception.- Parameters:
aMessage- the message
-
UnmarshalException
public UnmarshalException(String aMessage, int aOffset, Throwable aCause)
Instantiates a new unmarshal exception.- Parameters:
aMessage- The exception message.aOffset- The offset in the char sequence causing problems.aCause- The originating exception in question.
-
UnmarshalException
public UnmarshalException(String aMessage, int aOffset)
Instantiates a new unmarshal exception.- Parameters:
aMessage- the messageaOffset- The offset in the char sequence causing problems.
-
UnmarshalException
public UnmarshalException(String message, Throwable cause)
Instantiates a new unmarshal exception.- Parameters:
message- the messagecause- the cause
-
UnmarshalException
public UnmarshalException(Throwable cause)
Instantiates a new unmarshal exception.- Parameters:
cause- the cause
-
UnmarshalException
public UnmarshalException(String aMessage, String aErrorCode)
Instantiates a new unmarshal exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
UnmarshalException
public UnmarshalException(String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new unmarshal exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
-