Class VerifyRuntimeException
java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.exception.VerifyRuntimeException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
A verify exception is thrown in case the verification of the result (of an
algorithm) failed. This exception is thrown at runtime in case the
VerifyMode is set to VerifyMode#VERFIY- See Also:
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
ConstructorsConstructorDescriptionVerifyRuntimeException(String aMessage) Instantiates the classVerifyRuntimeException.VerifyRuntimeException(String aMessage, String aErrorCode) Instantiates the classVerifyRuntimeException.VerifyRuntimeException(String aMessage, Throwable aCause) Instantiates the classVerifyRuntimeException.VerifyRuntimeException(String aMessage, Throwable aCause, String aErrorCode) Instantiates the classVerifyRuntimeException.VerifyRuntimeException(Throwable aCause) Instantiates the classVerifyRuntimeException.VerifyRuntimeException(Throwable aCause, String aErrorCode) Instantiates the classVerifyRuntimeException. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCode, getMessageMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.refcodes.exception.Trap
getPatternArguments, toLocalizedMessage, toMessage, toMessage, toMessage, toShortLocalizedMessage, toShortMessage
-
Constructor Details
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-
VerifyRuntimeException
Instantiates the classVerifyRuntimeException.- See Also:
-