java.lang.Object
java.lang.Throwable
java.lang.Exception
java.lang.RuntimeException
org.refcodes.exception.AbstractRuntimeException
org.refcodes.exception.VerifyRuntimeException
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
public class VerifyRuntimeException extends AbstractRuntimeException
A verify exception is thrown in case the verification of the result (of an
algorithm) failed. This exception is thrown at runtime in case the
VerifyMode is set to VerifyMode#VERFIY- See Also:
- Serialized Form
-
Nested Class Summary
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty -
Constructor Summary
Constructors Constructor Description VerifyRuntimeException(String aMessage)Instantiates a new verify runtime exception.VerifyRuntimeException(String aMessage, String aErrorCode)Instantiates a new verify runtime exception.VerifyRuntimeException(String message, Throwable cause)Instantiates a new verify runtime exception.VerifyRuntimeException(String aMessage, Throwable aCause, String aErrorCode)Instantiates a new verify runtime exception.VerifyRuntimeException(Throwable cause)Instantiates a new verify runtime exception.VerifyRuntimeException(Throwable aCause, String aErrorCode)Instantiates a new verify runtime exception. -
Method Summary
Methods inherited from class org.refcodes.exception.AbstractRuntimeException
getErrorCodeMethods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
Constructor Details
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
aMessage- the message
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
message- the messagecause- the cause
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
cause- the cause
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
VerifyRuntimeException
Instantiates a new verify runtime exception.- Parameters:
aCause- the causeaErrorCode- the error code
-