- java.lang.Object
-
- java.lang.Throwable
-
- java.lang.Exception
-
- org.refcodes.exception.AbstractException
-
- org.refcodes.exception.VetoException
-
- All Implemented Interfaces:
Serializable,ErrorCodeAccessor,Trap
public class VetoException extends AbstractException implements Serializable
Thrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation. It's occurrence is unpredictable for the caller of the operation.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classVetoException.VetoRuntimeExceptionThrown to signal that an operation is being vetoed by a third party observing the invocation of the given operation.-
Nested classes/interfaces inherited from interface org.refcodes.exception.ErrorCodeAccessor
ErrorCodeAccessor.ErrorCodeBuilder<B extends ErrorCodeAccessor.ErrorCodeBuilder<B>>, ErrorCodeAccessor.ErrorCodeMutator, ErrorCodeAccessor.ErrorCodeProperty
-
-
Constructor Summary
Constructors Constructor Description VetoException(String message)Instantiates a new veto exception.VetoException(String aMessage, String aErrorCode)Instantiates a new veto exception.VetoException(String message, Throwable cause)Instantiates a new veto exception.VetoException(String aMessage, Throwable aCause, String aErrorCode)Instantiates a new veto exception.VetoException(Throwable cause)Instantiates a new veto exception.VetoException(Throwable aCause, String aErrorCode)Instantiates a new veto exception.
-
Method Summary
-
Methods inherited from class org.refcodes.exception.AbstractException
getErrorCode
-
Methods inherited from class java.lang.Throwable
addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString
-
-
-
-
Constructor Detail
-
VetoException
public VetoException(String aMessage, String aErrorCode)
Instantiates a new veto exception.- Parameters:
aMessage- the messageaErrorCode- the error code
-
VetoException
public VetoException(String aMessage, Throwable aCause, String aErrorCode)
Instantiates a new veto exception.- Parameters:
aMessage- the messageaCause- the causeaErrorCode- the error code
-
VetoException
public VetoException(String message, Throwable cause)
Instantiates a new veto exception.- Parameters:
message- the messagecause- the cause
-
VetoException
public VetoException(String message)
Instantiates a new veto exception.- Parameters:
message- the message
-
VetoException
public VetoException(Throwable aCause, String aErrorCode)
Instantiates a new veto exception.- Parameters:
aCause- the causeaErrorCode- the error code
-
VetoException
public VetoException(Throwable cause)
Instantiates a new veto exception.- Parameters:
cause- the cause
-
-