Uses of Enum Class
org.refcodes.exception.MessageDetails
-
Uses of MessageDetails in org.refcodes.exception
Methods in org.refcodes.exception that return MessageDetailsModifier and TypeMethodDescriptionstatic MessageDetailsReturns the enum constant of this class with the specified name.static MessageDetails[]MessageDetails.values()Returns an array containing the constants of this enum class, in the order they are declared.Methods in org.refcodes.exception with parameters of type MessageDetailsModifier and TypeMethodDescriptiondefault StringTrap.toMessage(MessageDetails aMessageDetails) Generates a message using the providedMessageDetailsenumeration defining the message's detail level.